[OpenWrt-Devel] [PATCH 3/4] ar8216: adjust ATU flushing in case of link changes

Heiner Kallweit hkallweit1 at gmail.com
Sat Jan 31 04:28:21 EST 2015


If a link goes down, don't flush the complete ARL table.
Only flush the entries for the respective port.
Don't touch ARL table if a link goes up.

Signed-off-by: Heiner Kallweit <hkallweit1 at gmail.com>
---
 target/linux/generic/files/drivers/net/phy/ar8216.c | 10 ++++------
 1 file changed, 4 insertions(+), 6 deletions(-)

diff --git a/target/linux/generic/files/drivers/net/phy/ar8216.c b/target/linux/generic/files/drivers/net/phy/ar8216.c
index f4c7b8d..9065915 100644
--- a/target/linux/generic/files/drivers/net/phy/ar8216.c
+++ b/target/linux/generic/files/drivers/net/phy/ar8216.c
@@ -1882,13 +1882,13 @@ ar8xxx_check_link_states(struct ar8xxx_priv *priv)
 
 		priv->link_up[i] = link_new;
 		changed = true;
+		/* flush ARL entries for this port if it went down*/
+		if (!link_new)
+			priv->chip->atu_flush_port(priv, i);
 		dev_info(&priv->phy->dev, "Port %d is %s\n",
 			 i, link_new ? "up" : "down");
 	}
 
-	if (changed)
-		priv->chip->atu_flush(priv);
-
 	mutex_unlock(&priv->reg_mutex);
 
 	return changed;
@@ -1900,9 +1900,7 @@ ar8xxx_phy_read_status(struct phy_device *phydev)
 	struct ar8xxx_priv *priv = phydev->priv;
 	struct switch_port_link link;
 
 	/* check for link changes and flush ATU
 	 * if a change was detected
 	 */
 	if (phydev->state == PHY_CHANGELINK)
 		ar8xxx_check_link_states(priv);
 
@@ -1900,9 +1900,7 @@ ar8xxx_phy_read_status(struct phy_device *phydev)
 	struct switch_port_link link;
 
-	/* check for link changes and flush ATU
-	 * if a change was detected
-	 */
+	/* check for switch port link changes */
 	if (phydev->state == PHY_CHANGELINK)
 		ar8xxx_check_link_states(priv);
-- 
2.2.2
_______________________________________________
openwrt-devel mailing list
openwrt-devel at lists.openwrt.org
https://lists.openwrt.org/cgi-bin/mailman/listinfo/openwrt-devel



More information about the openwrt-devel mailing list